# Copyright (C) 2024 Manuel Bustillo

require 'swagger_helper'

RSpec.describe 'groups', type: :request do
  path '/{slug}/groups' do
    get('list groups') do
      tags 'Groups'
      produces 'application/json'
      parameter Swagger::Schema::SLUG
      response(200, 'successful') do
        schema type: :array,
               items: {
                 type: :object,
                 required: %i[id name icon parent_id color total considered invited confirmed declined tentative],
                 properties: {
                   id: { type: :string, format: :uuid, required: true },
                   name: { type: :string },
                   icon: { type: :string, example: 'pi pi-crown', description: 'The CSS classes used by the icon' },
                   parent_id: { type: :string, format: :uuid },
                   color: { type: :string, pattern: '^#(?:[0-9a-fA-F]{3}){1,2}$' },
                   total: { type: :integer, minimum: 0, description: 'Total number of guests in any status' },
                   considered: { type: :integer, minimum: 0 },
                   invited: { type: :integer, minimum: 0 },
                   confirmed: { type: :integer, minimum: 0 },
                   declined: { type: :integer, minimum: 0 },
                   tentative: { type: :integer, minimum: 0 }
                 }
               }
        xit
      end
      regular_api_responses
    end
  end
end
